# sha256 for password
import hashlib
import datetime
import gb2260
import random

def get_sha256(password: str):
    str = hashlib.sha256(password.encode('utf-8')).hexdigest()
    return str

def get_time(type):
    if type == 'now':
        return str(datetime.datetime.now().replace(microsecond=0))
    elif type == 'today':
        return str(datetime.date.today())
    else:
        return None

def cl_build(current_district):
    div_result = []
    try:
        division = gb2260.get(current_district)
        for current in division.stack():
            temp = str(u'{0}'.format(current.name))
            div_result.append(temp)
            # use "-" to split str
        return("-".join(str(i) for i in div_result))
    except:
        return None

## not grace :(
def current_location(currentDistrict, currentCity):
    cl = cl_build(currentDistrict)
    if cl == None:
        cl = cl_build(currentCity)
    if cl == None:
        return None
    return cl

def random_temp():
    return round(random.uniform(36.0,37.2), 2)



from os import path as os_path
from setuptools import setup

this_directory = os_path.abspath(os_path.dirname(__file__))

# 读取文件内容


def read_file(filename):
    with open(os_path.join(this_directory, filename), encoding='utf-8') as f:
        long_description = f.read()
    return long_description

# 获取依赖


def read_requirements(filename):
    return [line.strip() for line in read_file(filename).splitlines()
            if not line.startswith('#')]


setup(name='litncov',
      version='0.0.1',
      description='A ncov report library and tool for LIT(Luoyang Institute of Science and Technology)',
      url='http://github.com/icepie/lit-ncov-report',
      author='Tea',
      author_email='icepie.dev@gmail.com',
      license='MIT',
      packages=['litncov'],
      install_requires=read_requirements('requirements.txt'),
      python_requires='>=3.6')
